==> haskell-uri-encode-1.5.0.7-314.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-JIBYONkNIhCHZjmfBPowzS
key:                  uri-encode-1.5.0.7-JIBYONkNIhCHZjmfBPowzS
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  e489c7dce598ba1403ae909fee69e7ab
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-JIBYONkNIhCHZjmfBPowzS
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS text-2.0.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.7-315-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-7znw3Txb6UEDNB9RHayVJK
key:                  uri-encode-1.5.0.7-7znw3Txb6UEDNB9RHayVJK
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  c8187d034d7be7e09939264dc93702e2
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-7znw3Txb6UEDNB9RHayVJK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
